//
//  ViewController.m
//  ImageSwitcher
//
//  Created by Ken Anderson on 10/17/11.
//  Copyright (c) 2011 University of Colorado, Boulder. All rights reserved.
//

#import "ViewController.h"

@interface ViewController ()

@property (nonatomic, assign) UIImageView* front;
@property (nonatomic, assign) UIImageView* back;
@property (nonatomic, assign) NSInteger current;

- (void) pageTurning: (UIPageControl*) sender;
- (void) handleSwipe:(UISwipeGestureRecognizer *) sender;

@end

@implementation ViewController

@synthesize back=_back;
@synthesize current=_current;
@synthesize front=_front;
@synthesize imageOne=_imageOne;
@synthesize imageTwo=_imageTwo;
@synthesize pages=_pages;

#pragma mark - View lifecycle

- (void)viewDidLoad {
    [super viewDidLoad];
    
    self.imageOne.image = [UIImage imageNamed:@"Aragorn.jpg"];
    
    self.current = 0;
    
    self.front = self.imageOne;
    self.back = self.imageTwo;
    
    [self.imageOne setHidden:NO];
    [self.imageTwo setHidden:YES];
    
    [self.pages addTarget:self
                   action:@selector(pageTurning:)
         forControlEvents:UIControlEventValueChanged];
    
    UISwipeGestureRecognizer *swipeRight = [[UISwipeGestureRecognizer alloc] initWithTarget:self action:@selector(handleSwipe:)];
	UISwipeGestureRecognizer *swipeLeft  = [[UISwipeGestureRecognizer alloc] initWithTarget:self action:@selector(handleSwipe:)];
	
	[swipeRight setDirection:UISwipeGestureRecognizerDirectionRight];
	[swipeLeft setDirection:UISwipeGestureRecognizerDirectionLeft];
	
	[self.view addGestureRecognizer:swipeRight];
	[self.view addGestureRecognizer:swipeLeft];

    [swipeRight release];
    [swipeLeft release];
    
}

- (void)viewDidUnload {
    self.imageOne = nil;
    self.imageTwo = nil;
    self.pages = nil;
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}

- (void)dealloc {
    [_imageOne release];
    [_imageTwo release];
    [_pages release];
    [super dealloc];
}

- (void) pageTurning: (UIPageControl*) sender {
    NSInteger nextPage = [sender currentPage];
    switch (nextPage) {
        case 0:
            self.back.image = [UIImage imageNamed:@"Aragorn.jpg"];
            break;
        case 1:
            self.back.image = [UIImage imageNamed:@"Gollum.jpg"];
            break;
        case 2:
            self.back.image = [UIImage imageNamed:@"Legolas.jpg"];
            break;
        case 3:
            self.back.image = [UIImage imageNamed:@"Sauron.jpg"];
            break;
        case 4:
            self.back.image = [UIImage imageNamed:@"theTowers.jpg"];
            break;
        default:
            break;
    }
    
    UIViewAnimationOptions options;
    
    if (self.current < nextPage) {
        options = UIViewAnimationOptionTransitionFlipFromLeft;
        // options = UIViewAnimationOptionTransitionCurlUp;
        // options = UIViewAnimationOptionTransitionCrossDissolve;
    } else {
        options = UIViewAnimationOptionTransitionFlipFromRight;
        // options = UIViewAnimationOptionTransitionCurlDown;
        // options = UIViewAnimationOptionTransitionCrossDissolve;
    }
    
    [UIView transitionWithView:self.view
                      duration:1.0
                       options:options
                    animations:^{
                        [self.front setHidden:YES];
                        [self.back setHidden:NO];
                    }
                    completion:^(BOOL finished) {
						if (finished) {
							UIImageView *temp = self.front;
							self.front = self.back;
							self.back = temp;
                            
                            self.current = nextPage;
						}
					}];
}

- (void) handleSwipe:(UISwipeGestureRecognizer *) sender {
	UISwipeGestureRecognizerDirection direction = [sender direction];
	switch (direction) {
		case UISwipeGestureRecognizerDirectionLeft:
			if (self.pages.currentPage > 0) {
                self.pages.currentPage = self.pages.currentPage - 1;
				[self pageTurning:self.pages];
			}
			break;
		case UISwipeGestureRecognizerDirectionRight:
			if (self.pages.currentPage < 4) {
				self.pages.currentPage = self.pages.currentPage + 1;
				[self pageTurning:self.pages];
			}
			break;
		default:
			break;
	}
}

@end
